@@ -186,8 +186,9 @@ AttachmentIconView::AttachmentIconView(QWidget *parent)
 
 QUrl AttachmentIconView::tempFileForAttachment(const KCalCore::Attachment::Ptr &attachment) const
 {
-    if (mTempFiles.contains(attachment)) {
-        return mTempFiles.value(attachment);
+    const QUrl url = mTempFiles.value(attachment);
+    if (url.isValid()) {
+        return url;
     }
     QTemporaryFile *file;
 
@@ -216,7 +217,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
     // create a list of the URL:s that we want to drag
     QList<QUrl> urls;
     QStringList labels;
-    foreach (QListWidgetItem *it, items) {
+    for (QListWidgetItem *it : items) {
         if (it->isSelected()) {
             AttachmentIconItem *item = static_cast<AttachmentIconItem *>(it);
             if (item->isBinary()) {
@@ -236,7 +237,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
     }
 
     QMap<QString, QString> metadata;
-    metadata[QStringLiteral("labels")] = labels.join(QStringLiteral(":"));
+    metadata[QStringLiteral("labels")] = labels.join(QLatin1Char(':'));
 
     QMimeData *mimeData = new QMimeData;
     mimeData->setUrls(urls);
