@@ -22,6 +22,7 @@
 
 #include "individualmailcomponentfactory.h"
 #include "individualmaildialog.h"
+#include "helper_p.h"
 
 #include <CalendarSupport/KCalPrefs>
 
@@ -41,8 +42,8 @@ IndividualMessageQueueJob::IndividualMessageQueueJob(const KIdentityManagement::
     , mUpdate(update)
     , mEdit(edit)
     , mIdentity(identity)
-    , mQueueJob(0)
-    , mComposerJob(0)
+    , mQueueJob(nullptr)
+    , mComposerJob(nullptr)
 {
 }
 
@@ -52,7 +53,7 @@ void IndividualMessageQueueJob::start()
     QSet<QString> attendeesCc(QSet<QString>::fromList(addressAttribute().cc()));
 
     QStringList attendeesAutoTo,  attendeesAutoCc;
-    foreach (const KCalCore::Attendee::Ptr &attendee, mUpdate) {
+    for (const KCalCore::Attendee::Ptr &attendee : qAsConst(mUpdate)) {
         if (attendeesTo.contains(attendee->email())) {
             attendeesAutoTo.append(attendee->fullName());
         }
@@ -65,7 +66,7 @@ void IndividualMessageQueueJob::start()
     }
 
     QStringList attendeesComposerTo,  attendeesComposerCc;
-    foreach (const KCalCore::Attendee::Ptr &attendee, mEdit) {
+    for (const KCalCore::Attendee::Ptr &attendee : qAsConst(mEdit)) {
         if (attendeesTo.contains(attendee->email())) {
             attendeesComposerTo.append(attendee->fullName());
         }
@@ -115,10 +116,10 @@ void IndividualMessageQueueJob::handleJobFinished(KJob *job)
     if (job->error()) {
         if (job == mQueueJob && mComposerJob) {
             mComposerJob->kill();
-            mComposerJob = 0;
+            mComposerJob = nullptr;
         } else if (job == mComposerJob && mQueueJob) {
             mQueueJob->kill();
-            mQueueJob = 0;
+            mQueueJob = nullptr;
         }
         setError(job->error());
         setErrorText(job->errorString());
@@ -129,12 +130,12 @@ void IndividualMessageQueueJob::handleJobFinished(KJob *job)
         if (!mComposerJob) {
             emitResult();
         }
-        mQueueJob = 0;
+        mQueueJob = nullptr;
     } else {
         if (!mQueueJob) {
             emitResult();
         }
-        mComposerJob = 0;
+        mComposerJob = nullptr;
     }
 
 }
@@ -144,7 +145,7 @@ void IndividualMessageQueueJob::handleJobFinished(KJob *job)
 IndividualMailITIPHandlerDialogDelegate::IndividualMailITIPHandlerDialogDelegate(const KCalCore::Incidence::Ptr &incidence,
         KCalCore::iTIPMethod method, QWidget *parent)
     : Akonadi::ITIPHandlerDialogDelegate(incidence, method, parent),
-      mDialog(Q_NULLPTR)
+      mDialog(nullptr)
 {
 }
 
